==> u61-0.2.0.tar.gz: u61-0.2.0/src/clientdispatcher.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   clientdispatcher.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: the client dispatcher basically sends messages to the
 *              remote server, which will send them to the right machine
 */


/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "clientdispatcher.h"

/*---------------------------------------------------------------------------
 variants
 ---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*
 * creates a dispatcher
 */
U61_ClientDispatcher::U61_ClientDispatcher() : U61_Dispatcher()
{
}

/*--------------------------------------------------------------------------*/
/*
 * deletes a dispatcher
 */
U61_ClientDispatcher::~U61_ClientDispatcher()
{
}

==> u61-0.3.2.tar.gz: u61-0.3.2/src/clientdispatcher.cpp <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   clientdispatcher.cpp
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: the client dispatcher basically sends messages to the
 *              remote server, which will send them to the right machine
 */


/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include "clientdispatcher.h"

/*---------------------------------------------------------------------------
 variants
 ---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------
 functions
 ---------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------*/
/*
 * creates a dispatcher
 */
U61_ClientDispatcher::U61_ClientDispatcher() : U61_Dispatcher()
{
  connection=NULL;
}

/*--------------------------------------------------------------------------*/
/*
 * Opens the connection with the server
 */
void U61_ClientDispatcher::open(U61_Connection *c)
{
  connection=c;
}

/*--------------------------------------------------------------------------*/
/*
 * Closes the connection with the server
 */
void U61_ClientDispatcher::close()
{
  connection=NULL;
}

/*--------------------------------------------------------------------------*/
/*
 * sends an event to no one since we're in a local game
 */
bool U61_ClientDispatcher::send(U61_Event evt)
{
  bool ok=true;
 
  if (connection!=NULL)
    {
      ok=connection->send(evt);
    }

  return ok;
}

/*--------------------------------------------------------------------------*/
/*
 * returns always false since no events can be from remote machines when
 * in local mode. Should never be called.
 */
bool U61_ClientDispatcher::recv(U61_Event *evt)
{
  bool ok=false;

  if (connection!=NULL)
    {
      ok=connection->recv(evt);
    }

  return ok;
} 

/*--------------------------------------------------------------------------*/
/*
 * returns true if a packet is available
 */
bool  U61_ClientDispatcher::peek()
{
  bool result=false;

  if (connection!=NULL)
    {
      result=connection->peek();
    }

  return result;
}
